==> grib-api_1.7.0.orig.tar.gz: grib_api-1.7.0/fortran/grib_api_f77.h <==
      integer grib_open_file
      external grib_open_file
      integer grib_close_file
      external grib_close_file
      integer grib_read_file
      external grib_read_file
      integer grib_new_from_message
      external grib_new_from_message
      integer grib_new_from_template
      external grib_new_from_template
      integer grib_clone
      external grib_clone
      integer grib_new_from_file
      external grib_new_from_file
      integer grib_multi_support_on
      external grib_multi_support_on
      integer grib_multi_support_off
      external grib_multi_support_off
      integer grib_gribex_mode_on
      external grib_gribex_mode_on
      integer grib_gribex_mode_off
      external grib_gribex_mode_off
      integer grib_release
      external grib_release
	  integer grib_get_data
	  external grib_get_data
      integer grib_iterator_new
      external grib_iterator_new
      integer grib_iterator_next
      external grib_iterator_next
      integer grib_iterator_delete
      external grib_iterator_delete
      integer grib_dump
      external grib_dump
      integer grib_get_error_string
      external grib_get_error_string
      integer grib_get_size
      external grib_get_size
      integer grib_get_int
      external grib_get_int
      integer grib_get_int_array
      external grib_get_int_array
      integer grib_set_int_array
      external grib_set_int_array
      integer grib_set_int
      external grib_set_int
      integer grib_set_missing
      integer grib_set_real4
      external grib_set_real4
      integer grib_get_real4
      external grib_get_real4
      integer grib_get_real4_element
      external grib_get_real4_element
      integer grib_get_real4_array
      external grib_get_real4_array
      integer grib_set_real4_array
      external grib_set_real4_array
      integer grib_set_real8
      external grib_set_real8
      integer grib_get_real8
      external grib_get_real8
      integer grib_get_real8_element
      external grib_get_real8_element
      integer grib_get_real8_array
      external grib_get_real8_array
      integer grib_set_real8_array
      external grib_set_real8_array
      integer grib_get_string
      external grib_get_string
      integer grib_set_string
      external grib_set_string
      integer grib_get_message_size
      external grib_get_message_size
      integer grib_write
      external grib_write
      integer grib_multi_write
      external grib_multi_write
      integer grib_multi_append
      external grib_multi_append
      integer grib_keys_iterator_new
      external grib_keys_iterator_new
      integer grib_keys_iterator_next
      external grib_keys_iterator_next
      integer grib_keys_iterator_delete
      external grib_keys_iterator_delete
      integer grib_skip_computed
      external grib_skip_computed
      integer grib_skip_coded
      external grib_skip_coded
      integer grib_skip_edition_specific
      external grib_skip_edition_specific
      integer grib_skip_duplicates
      external grib_skip_duplicates
      integer grib_skip_read_only
      external grib_skip_read_only
      integer grib_skip_function
      external grib_skip_function
      integer grib_keys_iterator_get_name
      external grib_keys_iterator_get_name
      integer grib_keys_iterator_rewind
      external grib_keys_iterator_rewind

==> grib-api_1.10.4.orig.tar.gz: grib_api-1.10.4/fortran/grib_api_f77.h <==
      integer grib_open_file
      external grib_open_file
      integer grib_close_file
      external grib_close_file
      integer grib_read_file
      external grib_read_file
      integer grib_new_from_message
      external grib_new_from_message
      integer grib_new_from_template
      external grib_new_from_template
      integer grib_clone
      external grib_clone
      integer grib_new_from_file
      external grib_new_from_file
      integer grib_multi_support_on
      external grib_multi_support_on
      integer grib_multi_support_off
      external grib_multi_support_off
      integer grib_gribex_mode_on
      external grib_gribex_mode_on
      integer grib_gribex_mode_off
      external grib_gribex_mode_off
      integer grib_release
      external grib_release
	  integer grib_get_data
	  external grib_get_data
      integer grib_iterator_new
      external grib_iterator_new
      integer grib_iterator_next
      external grib_iterator_next
      integer grib_iterator_delete
      external grib_iterator_delete
      integer grib_dump
      external grib_dump
      integer grib_get_error_string
      external grib_get_error_string
      integer grib_get_size
      external grib_get_size
      integer grib_get_int
      external grib_get_int
      integer grib_get_int_array
      external grib_get_int_array
      integer grib_set_int_array
      external grib_set_int_array
      integer grib_set_int
      external grib_set_int
      integer grib_set_missing
      integer grib_set_real4
      external grib_set_real4
      integer grib_get_real4
      external grib_get_real4
      integer grib_get_real4_element
      external grib_get_real4_element
      integer grib_get_real4_array
      external grib_get_real4_array
      integer grib_set_real4_array
      external grib_set_real4_array
      integer grib_set_real8
      external grib_set_real8
      integer grib_get_real8
      external grib_get_real8
      integer grib_get_real8_element
      external grib_get_real8_element
      integer grib_get_real8_array
      external grib_get_real8_array
      integer grib_set_real8_array
      external grib_set_real8_array
      integer grib_get_string
      external grib_get_string
      integer grib_is_missing
      external grib_is_missing
      integer grib_is_defined
      external grib_is_defined
      integer grib_set_string
      external grib_copy_namespace
      integer grib_copy_namespace
      external grib_set_string
      integer grib_get_message_size
      external grib_get_message_size
      integer grib_write
      external grib_write
      integer grib_multi_write
      external grib_multi_write
      integer grib_multi_append
      external grib_multi_append
      integer grib_keys_iterator_new
      external grib_keys_iterator_new
      integer grib_keys_iterator_next
      external grib_keys_iterator_next
      integer grib_keys_iterator_delete
      external grib_keys_iterator_delete
      integer grib_skip_computed
      external grib_skip_computed
      integer grib_skip_coded
      external grib_skip_coded
      integer grib_skip_edition_specific
      external grib_skip_edition_specific
      integer grib_skip_duplicates
      external grib_skip_duplicates
      integer grib_skip_read_only
      external grib_skip_read_only
      integer grib_skip_function
      external grib_skip_function
      integer grib_keys_iterator_get_name
      external grib_keys_iterator_get_name
      integer grib_keys_iterator_rewind
      external grib_keys_iterator_rewind
